# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class HelpdeskClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def DescribeDocument(self, request, **kwargs):
        path = "/helpdesk/documents/"+urllib.parse.quote(request.document_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.document_id = ""

        return self.transport.request(
            name="eolymp.helpdesk.Helpdesk/DescribeDocument",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.helpdesk.DescribeDocumentOutput"),
            **kwargs,
        )

    def ListDocuments(self, request, **kwargs):
        path = "/helpdesk/documents"

        return self.transport.request(
            name="eolymp.helpdesk.Helpdesk/ListDocuments",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.helpdesk.ListDocumentsOutput"),
            **kwargs,
        )

    def CreateDocument(self, request, **kwargs):
        path = "/helpdesk/documents"

        return self.transport.request(
            name="eolymp.helpdesk.Helpdesk/CreateDocument",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.helpdesk.CreateDocumentOutput"),
            **kwargs,
        )

    def UpdateDocument(self, request, **kwargs):
        path = "/helpdesk/documents/"+urllib.parse.quote(request.document_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.document_id = ""

        return self.transport.request(
            name="eolymp.helpdesk.Helpdesk/UpdateDocument",
            method="PUT",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.helpdesk.UpdateDocumentOutput"),
            **kwargs,
        )

    def DeleteDocument(self, request, **kwargs):
        path = "/helpdesk/documents/"+urllib.parse.quote(request.document_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.document_id = ""

        return self.transport.request(
            name="eolymp.helpdesk.Helpdesk/DeleteDocument",
            method="DELETE",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.helpdesk.DeleteDocumentOutput"),
            **kwargs,
        )

    def DescribePath(self, request, **kwargs):
        path = "/helpdesk/paths/"+urllib.parse.quote(request.path)

        # Cleanup URL parameters to avoid any ambiguity
        request.path = ""

        return self.transport.request(
            name="eolymp.helpdesk.Helpdesk/DescribePath",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.helpdesk.DescribePathOutput"),
            **kwargs,
        )

    def ListPaths(self, request, **kwargs):
        path = "/helpdesk/paths"

        return self.transport.request(
            name="eolymp.helpdesk.Helpdesk/ListPaths",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.helpdesk.ListPathsOutput"),
            **kwargs,
        )

    def ListParents(self, request, **kwargs):
        path = "/helpdesk/paths/"+urllib.parse.quote(request.path)+"/parents"

        # Cleanup URL parameters to avoid any ambiguity
        request.path = ""

        return self.transport.request(
            name="eolymp.helpdesk.Helpdesk/ListParents",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.helpdesk.ListParentsOutput"),
            **kwargs,
        )




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/resolver/resolver.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65olymp/resolver/resolver.proto\x12\x0f\x65olymp.resolver\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\"\x84\x03\n\x06Record\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x10\n\x08space_id\x18\x02 \x01(\t\x12\x0f\n\x07summary\x18\x03 \x01(\t\x12*\n\x04\x61uth\x18\n \x01(\x0b\x32\x1c.eolymp.resolver.Record.Auth\x12.\n\x06target\x18\x14 \x01(\x0b\x32\x1e.eolymp.resolver.Record.Target\x1aj\n\x04\x41uth\x12\x11\n\tclient_id\x18\n \x01(\t\x12\x15\n\rclient_secret\x18\x0b \x01(\t\x12\x0e\n\x06scopes\x18\x0c \x01(\t\x12\x11\n\ttoken_url\x18\x14 \x01(\t\x12\x15\n\rauthorize_url\x18\x1e \x01(\t\x1a\x41\n\x06Target\x12*\n\x04type\x18\x01 \x01(\x0e\x32\x1c.eolymp.resolver.Record.Type\x12\x0b\n\x03url\x18\x02 \x01(\t\"?\n\x04Type\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\t\n\x05SPACE\x10\x01\x12\x0b\n\x07\x43ONTEST\x10\x02\x12\x0e\n\nSCOREBOARD\x10\x03\" \n\x10ResolveNameInput\x12\x0c\n\x04name\x18\x01 \x01(\t\"o\n\x11ResolveNameOutput\x12*\n\x04\x61uth\x18\x01 \x01(\x0b\x32\x1c.eolymp.resolver.Record.Auth\x12.\n\x06target\x18\x02 \x01(\x0b\x32\x1e.eolymp.resolver.Record.Target2\x86\x01\n\x08Resolver\x12z\n\x0bResolveName\x12!.eolymp.resolver.ResolveNameInput\x1a\".eolymp.resolver.ResolveNameOutput\"$\xea\xe2\n\x0b\xf5\xe2\n\x00\x00HB\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0f\x12\r/names/{name}B3Z1github.com/eolymp/go-sdk/eolymp/resolver;resolverb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.resolver.resolver_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/resolver;resolver'
  _RESOLVER.methods_by_name['ResolveName']._options = None
  _RESOLVER.methods_by_name['ResolveName']._serialized_options = b'\352\342\n\013\365\342\n\000\000HB\370\342\nd\202\323\344\223\002\017\022\r/names/{name}'
  _RECORD._serialized_start=151
  _RECORD._serialized_end=539
  _RECORD_AUTH._serialized_start=301
  _RECORD_AUTH._serialized_end=407
  _RECORD_TARGET._serialized_start=409
  _RECORD_TARGET._serialized_end=474
  _RECORD_TYPE._serialized_start=476
  _RECORD_TYPE._serialized_end=539
  _RESOLVENAMEINPUT._serialized_start=541
  _RESOLVENAMEINPUT._serialized_end=573
  _RESOLVENAMEOUTPUT._serialized_start=575
  _RESOLVENAMEOUTPUT._serialized_end=686
  _RESOLVER._serialized_start=689
  _RESOLVER._serialized_end=823
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Record(_message.Message):
    __slots__ = ["auth", "key", "space_id", "summary", "target"]
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Auth(_message.Message):
        __slots__ = ["authorize_url", "client_id", "client_secret", "scopes", "token_url"]
        AUTHORIZE_URL_FIELD_NUMBER: _ClassVar[int]
        CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
        CLIENT_SECRET_FIELD_NUMBER: _ClassVar[int]
        SCOPES_FIELD_NUMBER: _ClassVar[int]
        TOKEN_URL_FIELD_NUMBER: _ClassVar[int]
        authorize_url: str
        client_id: str
        client_secret: str
        scopes: str
        token_url: str
        def __init__(self, client_id: _Optional[str] = ..., client_secret: _Optional[str] = ..., scopes: _Optional[str] = ..., token_url: _Optional[str] = ..., authorize_url: _Optional[str] = ...) -> None: ...
    class Target(_message.Message):
        __slots__ = ["type", "url"]
        TYPE_FIELD_NUMBER: _ClassVar[int]
        URL_FIELD_NUMBER: _ClassVar[int]
        type: Record.Type
        url: str
        def __init__(self, type: _Optional[_Union[Record.Type, str]] = ..., url: _Optional[str] = ...) -> None: ...
    AUTH_FIELD_NUMBER: _ClassVar[int]
    CONTEST: Record.Type
    KEY_FIELD_NUMBER: _ClassVar[int]
    SCOREBOARD: Record.Type
    SPACE: Record.Type
    SPACE_ID_FIELD_NUMBER: _ClassVar[int]
    SUMMARY_FIELD_NUMBER: _ClassVar[int]
    TARGET_FIELD_NUMBER: _ClassVar[int]
    UNSPECIFIED: Record.Type
    auth: Record.Auth
    key: str
    space_id: str
    summary: str
    target: Record.Target
    def __init__(self, key: _Optional[str] = ..., space_id: _Optional[str] = ..., summary: _Optional[str] = ..., auth: _Optional[_Union[Record.Auth, _Mapping]] = ..., target: _Optional[_Union[Record.Target, _Mapping]] = ...) -> None: ...

class ResolveNameInput(_message.Message):
    __slots__ = ["name"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class ResolveNameOutput(_message.Message):
    __slots__ = ["auth", "target"]
    AUTH_FIELD_NUMBER: _ClassVar[int]
    TARGET_FIELD_NUMBER: _ClassVar[int]
    auth: Record.Auth
    target: Record.Target
    def __init__(self, auth: _Optional[_Union[Record.Auth, _Mapping]] = ..., target: _Optional[_Union[Record.Target, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class JudgeClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def LookupContest(self, request, **kwargs):
        path = "/contests/__lookup"

        return self.transport.request(
            name="eolymp.judge.Judge/LookupContest",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.LookupContestOutput"),
            **kwargs,
        )

    def CreateContest(self, request, **kwargs):
        path = "/contests"

        return self.transport.request(
            name="eolymp.judge.Judge/CreateContest",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.CreateContestOutput"),
            **kwargs,
        )

    def DeleteContest(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/DeleteContest",
            method="DELETE",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.DeleteContestOutput"),
            **kwargs,
        )

    def UpdateContest(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/UpdateContest",
            method="PUT",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.UpdateContestOutput"),
            **kwargs,
        )

    def DescribeContest(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/DescribeContest",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.DescribeContestOutput"),
            **kwargs,
        )

    def ListContests(self, request, **kwargs):
        path = "/contests"

        return self.transport.request(
            name="eolymp.judge.Judge/ListContests",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.ListContestsOutput"),
            **kwargs,
        )

    def OpenContest(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/open"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/OpenContest",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.OpenContestOutput"),
            **kwargs,
        )

    def CloseContest(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/close"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/CloseContest",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.CloseContestOutput"),
            **kwargs,
        )

    def ConfigureRuntime(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/runtime"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/ConfigureRuntime",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.ConfigureRuntimeOutput"),
            **kwargs,
        )

    def DescribeRuntime(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/runtime"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/DescribeRuntime",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.DescribeRuntimeOutput"),
            **kwargs,
        )

    def ConfigureAppearance(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/appearance"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/ConfigureAppearance",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.ConfigureAppearanceOutput"),
            **kwargs,
        )

    def DescribeAppearance(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/appearance"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/DescribeAppearance",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.DescribeAppearanceOutput"),
            **kwargs,
        )

    def ConfigureScoring(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/scoring"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/ConfigureScoring",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.ConfigureScoringOutput"),
            **kwargs,
        )

    def DescribeScoring(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/scoring"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/DescribeScoring",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.DescribeScoringOutput"),
            **kwargs,
        )

    def ImportProblem(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/problems"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/ImportProblem",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.ImportProblemOutput"),
            **kwargs,
        )

    def SyncProblem(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/problems/"+urllib.parse.quote(request.problem_id)+"/sync"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/SyncProblem",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.SyncProblemOutput"),
            **kwargs,
        )

    def UpdateProblem(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/problems/"+urllib.parse.quote(request.problem_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/UpdateProblem",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.UpdateProblemOutput"),
            **kwargs,
        )

    def ListProblems(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/problems"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/ListProblems",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.ListProblemsOutput"),
            **kwargs,
        )

    def DescribeProblem(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/problems/"+urllib.parse.quote(request.problem_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/DescribeProblem",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.DescribeProblemOutput"),
            **kwargs,
        )

    def DescribeCodeTemplate(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/problems/"+urllib.parse.quote(request.problem_id)+"/templates/"+urllib.parse.quote(request.template_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""
        request.problem_id = ""
        request.template_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/DescribeCodeTemplate",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.DescribeCodeTemplateOutput"),
            **kwargs,
        )

    def LookupCodeTemplate(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/problems/"+urllib.parse.quote(request.problem_id)+"/lookup-template"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/LookupCodeTemplate",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.LookupCodeTemplateOutput"),
            **kwargs,
        )

    def ListStatements(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/problems/"+urllib.parse.quote(request.problem_id)+"/statements"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/ListStatements",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.ListStatementsOutput"),
            **kwargs,
        )

    def ListAttachments(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/problems/"+urllib.parse.quote(request.problem_id)+"/attachments"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/ListAttachments",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.ListAttachmentsOutput"),
            **kwargs,
        )

    def ListExamples(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/problems/"+urllib.parse.quote(request.problem_id)+"/examples"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/ListExamples",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.ListExamplesOutput"),
            **kwargs,
        )

    def DeleteProblem(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/problems/"+urllib.parse.quote(request.problem_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/DeleteProblem",
            method="DELETE",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.DeleteProblemOutput"),
            **kwargs,
        )

    def RetestProblem(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/problems/"+urllib.parse.quote(request.problem_id)+"/retest"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/RetestProblem",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.RetestProblemOutput"),
            **kwargs,
        )

    def AddParticipant(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/participants"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/AddParticipant",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.AddParticipantOutput"),
            **kwargs,
        )

    def EnableParticipant(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/participants/"+urllib.parse.quote(request.participant_id)+"/enable"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""
        request.participant_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/EnableParticipant",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.EnableParticipantOutput"),
            **kwargs,
        )

    def DisableParticipant(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/participants/"+urllib.parse.quote(request.participant_id)+"/disable"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""
        request.participant_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/DisableParticipant",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.DisableParticipantOutput"),
            **kwargs,
        )

    def UpdateParticipant(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/participants/"+urllib.parse.quote(request.participant_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""
        request.participant_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/UpdateParticipant",
            method="PUT",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.UpdateParticipantOutput"),
            **kwargs,
        )

    def RemoveParticipant(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/participants/"+urllib.parse.quote(request.participant_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""
        request.participant_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/RemoveParticipant",
            method="DELETE",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.RemoveParticipantOutput"),
            **kwargs,
        )

    def ListParticipants(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/participants"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/ListParticipants",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.ListParticipantsOutput"),
            **kwargs,
        )

    def DescribeParticipant(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/participants/"+urllib.parse.quote(request.participant_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""
        request.participant_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/DescribeParticipant",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.DescribeParticipantOutput"),
            **kwargs,
        )

    def IntrospectParticipant(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/introspect"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/IntrospectParticipant",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.IntrospectParticipantOutput"),
            **kwargs,
        )

    def JoinContest(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/join"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/JoinContest",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.JoinContestOutput"),
            **kwargs,
        )

    def StartContest(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/start"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/StartContest",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.StartContestOutput"),
            **kwargs,
        )

    def VerifyPasscode(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/verify-passcode"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/VerifyPasscode",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.VerifyPasscodeOutput"),
            **kwargs,
        )

    def EnterPasscode(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/enter-passcode"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/EnterPasscode",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.EnterPasscodeOutput"),
            **kwargs,
        )

    def ResetPasscode(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/participants/"+urllib.parse.quote(request.participant_id)+"/passcode"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""
        request.participant_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/ResetPasscode",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.ResetPasscodeOutput"),
            **kwargs,
        )

    def RemovePasscode(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/participants/"+urllib.parse.quote(request.participant_id)+"/passcode"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""
        request.participant_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/RemovePasscode",
            method="DELETE",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.RemovePasscodeOutput"),
            **kwargs,
        )

    def CreateSubmission(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/problems/"+urllib.parse.quote(request.problem_id)+"/submissions"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""
        request.problem_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/CreateSubmission",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.CreateSubmissionOutput"),
            **kwargs,
        )

    def ListSubmissions(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/submissions"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/ListSubmissions",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.ListSubmissionsOutput"),
            **kwargs,
        )

    def DescribeSubmission(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/submissions/"+urllib.parse.quote(request.submission_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""
        request.submission_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/DescribeSubmission",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.DescribeSubmissionOutput"),
            **kwargs,
        )

    def RetestSubmission(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/submissions/"+urllib.parse.quote(request.submission_id)+"/retest"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""
        request.submission_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/RetestSubmission",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.RetestSubmissionOutput"),
            **kwargs,
        )

    def CreateTicket(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/tickets"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/CreateTicket",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.CreateTicketOutput"),
            **kwargs,
        )

    def CloseTicket(self, request, **kwargs):
        path = "/tickets/"+urllib.parse.quote(request.ticket_id)+"/close"

        # Cleanup URL parameters to avoid any ambiguity
        request.ticket_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/CloseTicket",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.CloseTicketOutput"),
            **kwargs,
        )

    def OpenTicket(self, request, **kwargs):
        path = "/tickets/"+urllib.parse.quote(request.ticket_id)+"/open"

        # Cleanup URL parameters to avoid any ambiguity
        request.ticket_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/OpenTicket",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.OpenTicketOutput"),
            **kwargs,
        )

    def ReadTicket(self, request, **kwargs):
        path = "/tickets/"+urllib.parse.quote(request.ticket_id)+"/read"

        # Cleanup URL parameters to avoid any ambiguity
        request.ticket_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/ReadTicket",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.ReadTicketOutput"),
            **kwargs,
        )

    def DeleteTicket(self, request, **kwargs):
        path = "/tickets/"+urllib.parse.quote(request.ticket_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.ticket_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/DeleteTicket",
            method="DELETE",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.DeleteTicketOutput"),
            **kwargs,
        )

    def DescribeTicket(self, request, **kwargs):
        path = "/tickets/"+urllib.parse.quote(request.ticket_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.ticket_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/DescribeTicket",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.DescribeTicketOutput"),
            **kwargs,
        )

    def ListTickets(self, request, **kwargs):
        path = "/tickets"

        return self.transport.request(
            name="eolymp.judge.Judge/ListTickets",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.ListTicketsOutput"),
            **kwargs,
        )

    def ReplyTicket(self, request, **kwargs):
        path = "/tickets/"+urllib.parse.quote(request.ticket_id)+"/replies"

        # Cleanup URL parameters to avoid any ambiguity
        request.ticket_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/ReplyTicket",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.ReplyTicketOutput"),
            **kwargs,
        )

    def ListReplies(self, request, **kwargs):
        path = "/tickets/"+urllib.parse.quote(request.ticket_id)+"/replies"

        # Cleanup URL parameters to avoid any ambiguity
        request.ticket_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/ListReplies",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.ListRepliesOutput"),
            **kwargs,
        )

    def DeleteReply(self, request, **kwargs):
        path = "/tickets/"+urllib.parse.quote(request.ticket_id)+"/replies/"+urllib.parse.quote(request.reply_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.ticket_id = ""
        request.reply_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/DeleteReply",
            method="DELETE",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.DeleteReplyOutput"),
            **kwargs,
        )

    def UpdateReply(self, request, **kwargs):
        path = "/tickets/"+urllib.parse.quote(request.ticket_id)+"/replies/"+urllib.parse.quote(request.reply_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.ticket_id = ""
        request.reply_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/UpdateReply",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.UpdateReplyOutput"),
            **kwargs,
        )

    def CreateAnnouncement(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/announcements"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/CreateAnnouncement",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.CreateAnnouncementOutput"),
            **kwargs,
        )

    def UpdateAnnouncement(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/announcements/"+urllib.parse.quote(request.announcement_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""
        request.announcement_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/UpdateAnnouncement",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.UpdateAnnouncementOutput"),
            **kwargs,
        )

    def DeleteAnnouncement(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/announcements/"+urllib.parse.quote(request.announcement_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""
        request.announcement_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/DeleteAnnouncement",
            method="DELETE",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.DeleteAnnouncementOutput"),
            **kwargs,
        )

    def ReadAnnouncement(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/announcements/"+urllib.parse.quote(request.announcement_id)+"/read"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""
        request.announcement_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/ReadAnnouncement",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.ReadAnnouncementOutput"),
            **kwargs,
        )

    def DescribeAnnouncement(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/announcements/"+urllib.parse.quote(request.announcement_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""
        request.announcement_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/DescribeAnnouncement",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.DescribeAnnouncementOutput"),
            **kwargs,
        )

    def DescribeAnnouncementStatus(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/announcements/"+urllib.parse.quote(request.announcement_id)+"/status"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""
        request.announcement_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/DescribeAnnouncementStatus",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.DescribeAnnouncementStatusOutput"),
            **kwargs,
        )

    def ListAnnouncements(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/announcements"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/ListAnnouncements",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.ListAnnouncementsOutput"),
            **kwargs,
        )

    def IntrospectScore(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/introspect/score"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/IntrospectScore",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.IntrospectScoreOutput"),
            **kwargs,
        )

    def DescribeScore(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/participants/"+urllib.parse.quote(request.participant_id)+"/score"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""
        request.participant_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/DescribeScore",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.DescribeScoreOutput"),
            **kwargs,
        )

    def ImportScore(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/participants/"+urllib.parse.quote(request.participant_id)+"/scores"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""
        request.participant_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/ImportScore",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.ImportScoreOutput"),
            **kwargs,
        )

    def ListResult(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/results"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/ListResult",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.ListResultOutput"),
            **kwargs,
        )

    def RebuildScore(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/rebuild"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/RebuildScore",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.RebuildScoreOutput"),
            **kwargs,
        )

    def ListEntitlements(self, request, **kwargs):
        path = "/__judge/entitlements"

        return self.transport.request(
            name="eolymp.judge.Judge/ListEntitlements",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.ListEntitlementsOutput"),
            **kwargs,
        )

    def ListActivities(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/activities"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            name="eolymp.judge.Judge/ListActivities",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.ListActivitiesOutput"),
            **kwargs,
        )




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/cognito/user.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x65olymp/cognito/user.proto\x12\x0e\x65olymp.cognito\x1a\x1fgoogle/protobuf/timestamp.proto\"\x91\x04\n\x04User\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x0e\n\x06\x61\x63tive\x18\x04 \x01(\x08\x12\x0c\n\x04rank\x18) \x01(\r\x12\x32\n\nrank_trend\x18* \x01(\x0e\x32\x1e.eolymp.cognito.User.RankTrend\x12\x0c\n\x04name\x18\n \x01(\t\x12\x0f\n\x07picture\x18\x0b \x01(\t\x12\x0f\n\x07\x63ompany\x18\x0c \x01(\t\x12\x12\n\noccupation\x18\r \x01(\t\x12\x0f\n\x07\x63ountry\x18\x15 \x01(\t\x12\x0c\n\x04\x63ity\x18\x16 \x01(\t\x12\x14\n\x0c\x65mail_status\x18  \x01(\t\x12\x10\n\x08\x62irthday\x18! \x01(\t\x12\x31\n\rregistered_on\x18\" \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rlast_activity\x18# \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x37\n\x13username_changed_on\x18$ \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x37\n\x13password_changed_on\x18% \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\'\n\tRankTrend\x12\x08\n\x04NONE\x10\x00\x12\x06\n\x02UP\x10\x01\x12\x08\n\x04\x44OWN\x10\x02\x42\x31Z/github.com/eolymp/go-sdk/eolymp/cognito;cognitob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.cognito.user_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/cognito;cognito'
  _USER._serialized_start=79
  _USER._serialized_end=608
  _USER_RANKTREND._serialized_start=569
  _USER_RANKTREND._serialized_end=608
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/ranker/ranker.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.annotations import service_pb2 as eolymp_dot_annotations_dot_service__pb2
from eolymp.ranker import activity_pb2 as eolymp_dot_ranker_dot_activity__pb2
from eolymp.ranker import scoreboard_pb2 as eolymp_dot_ranker_dot_scoreboard__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65olymp/ranker/ranker.proto\x12\reolymp.ranker\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a eolymp/annotations/service.proto\x1a\x1c\x65olymp/ranker/activity.proto\x1a\x1e\x65olymp/ranker/scoreboard.proto\x1a!eolymp/wellknown/expression.proto\"F\n\x15\x43reateScoreboardInput\x12-\n\nscoreboard\x18\x01 \x01(\x0b\x32\x19.eolymp.ranker.Scoreboard\"/\n\x16\x43reateScoreboardOutput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"]\n\x15UpdateScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12-\n\nscoreboard\x18\x02 \x01(\x0b\x32\x19.eolymp.ranker.Scoreboard\"\x18\n\x16UpdateScoreboardOutput\"/\n\x16RebuildScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\".\n\x17RebuildScoreboardOutput\x12\x13\n\x0b\x61\x63tivity_id\x18\x01 \x01(\t\".\n\x15\x44\x65leteScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"\x18\n\x16\x44\x65leteScoreboardOutput\"H\n\x17\x44\x65scribeScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x16\n\x0escoreboard_key\x18\x02 \x01(\t\"I\n\x18\x44\x65scribeScoreboardOutput\x12-\n\nscoreboard\x18\x01 \x01(\x0b\x32\x19.eolymp.ranker.Scoreboard\"\xa7\x01\n\x14ListScoreboardsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12;\n\x07\x66ilters\x18( \x01(\x0b\x32*.eolymp.ranker.ListScoreboardsInput.Filter\x1a\x34\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"P\n\x15ListScoreboardsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.ranker.Scoreboard\"F\n\x1a\x44\x65scribeScoreboardRowInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x02 \x01(\t\"I\n\x1b\x44\x65scribeScoreboardRowOutput\x12*\n\x03row\x18\x01 \x01(\x0b\x32\x1d.eolymp.ranker.Scoreboard.Row\"\xcb\x01\n\x17ListScoreboardRowsInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12>\n\x07\x66ilters\x18( \x01(\x0b\x32-.eolymp.ranker.ListScoreboardRowsInput.Filter\x1a;\n\x06\x46ilter\x12\x31\n\tmember_id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"W\n\x18ListScoreboardRowsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12,\n\x05items\x18\x02 \x03(\x0b\x32\x1d.eolymp.ranker.Scoreboard.Row\"c\n\x18\x41\x64\x64ScoreboardColumnInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x30\n\x06\x63olumn\x18\x02 \x01(\x0b\x32 .eolymp.ranker.Scoreboard.Column\".\n\x19\x41\x64\x64ScoreboardColumnOutput\x12\x11\n\tcolumn_id\x18\x01 \x01(\t\"G\n\x1b\x44\x65leteScoreboardColumnInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x11\n\tcolumn_id\x18\x02 \x01(\t\"\x1e\n\x1c\x44\x65leteScoreboardColumnOutput\"I\n\x1d\x44\x65scribeScoreboardColumnInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x11\n\tcolumn_id\x18\x02 \x01(\t\"R\n\x1e\x44\x65scribeScoreboardColumnOutput\x12\x30\n\x06\x63olumn\x18\x01 \x01(\x0b\x32 .eolymp.ranker.Scoreboard.Column\"3\n\x1aListScoreboardColumnsInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"]\n\x1bListScoreboardColumnsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12/\n\x05items\x18\x02 \x03(\x0b\x32 .eolymp.ranker.Scoreboard.Column\"J\n\x13ListActivitiesInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"M\n\x14ListActivitiesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.ranker.Activity2\xdb\x13\n\x06Ranker\x12\xa3\x01\n\x10\x43reateScoreboard\x12$.eolymp.ranker.CreateScoreboardInput\x1a%.eolymp.ranker.CreateScoreboardOutput\"B\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x0e\"\x0c/scoreboards\x12\xb3\x01\n\x10UpdateScoreboard\x12$.eolymp.ranker.UpdateScoreboardInput\x1a%.eolymp.ranker.UpdateScoreboardOutput\"R\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e\x1a\x1c/scoreboards/{scoreboard_id}\x12\xbe\x01\n\x11RebuildScoreboard\x12%.eolymp.ranker.RebuildScoreboardInput\x1a&.eolymp.ranker.RebuildScoreboardOutput\"Z\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02&\"$/scoreboards/{scoreboard_id}/rebuild\x12\xb3\x01\n\x10\x44\x65leteScoreboard\x12$.eolymp.ranker.DeleteScoreboardInput\x1a%.eolymp.ranker.DeleteScoreboardOutput\"R\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x1e*\x1c/scoreboards/{scoreboard_id}\x12\xb8\x01\n\x12\x44\x65scribeScoreboard\x12&.eolymp.ranker.DescribeScoreboardInput\x1a\'.eolymp.ranker.DescribeScoreboardOutput\"Q\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1e\x12\x1c/scoreboards/{scoreboard_id}\x12\x9f\x01\n\x0fListScoreboards\x12#.eolymp.ranker.ListScoreboardsInput\x1a$.eolymp.ranker.ListScoreboardsOutput\"A\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/scoreboards\x12\xd2\x01\n\x15\x44\x65scribeScoreboardRow\x12).eolymp.ranker.DescribeScoreboardRowInput\x1a*.eolymp.ranker.DescribeScoreboardRowOutput\"b\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02/\x12-/scoreboards/{scoreboard_id}/rows/{member_id}\x12\xbd\x01\n\x12ListScoreboardRows\x12&.eolymp.ranker.ListScoreboardRowsInput\x1a\'.eolymp.ranker.ListScoreboardRowsOutput\"V\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02#\x12!/scoreboards/{scoreboard_id}/rows\x12\xc4\x01\n\x13\x41\x64\x64ScoreboardColumn\x12\'.eolymp.ranker.AddScoreboardColumnInput\x1a(.eolymp.ranker.AddScoreboardColumnOutput\"Z\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02&\"$/scoreboards/{scoreboard_id}/columns\x12\xd9\x01\n\x16\x44\x65leteScoreboardColumn\x12*.eolymp.ranker.DeleteScoreboardColumnInput\x1a+.eolymp.ranker.DeleteScoreboardColumnOutput\"f\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x32*0/scoreboards/{scoreboard_id}/columns/{column_id}\x12\xde\x01\n\x18\x44\x65scribeScoreboardColumn\x12,.eolymp.ranker.DescribeScoreboardColumnInput\x1a-.eolymp.ranker.DescribeScoreboardColumnOutput\"e\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x32\x12\x30/scoreboards/{scoreboard_id}/columns/{column_id}\x12\xc9\x01\n\x15ListScoreboardColumns\x12).eolymp.ranker.ListScoreboardColumnsInput\x1a*.eolymp.ranker.ListScoreboardColumnsOutput\"Y\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02&\x12$/scoreboards/{scoreboard_id}/columns\x12\xb3\x01\n\x0eListActivities\x12\".eolymp.ranker.ListActivitiesInput\x1a#.eolymp.ranker.ListActivitiesOutput\"X\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02)\x12\'/scoreboards/{scoreboard_id}/activities\x1a\x06\xb2\xe3\n\x02\x08\x01\x42/Z-github.com/eolymp/go-sdk/eolymp/ranker;rankerb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.ranker.ranker_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/ranker;ranker'
  _RANKER._options = None
  _RANKER._serialized_options = b'\262\343\n\002\010\001'
  _RANKER.methods_by_name['CreateScoreboard']._options = None
  _RANKER.methods_by_name['CreateScoreboard']._serialized_options = b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\016\"\014/scoreboards'
  _RANKER.methods_by_name['UpdateScoreboard']._options = None
  _RANKER.methods_by_name['UpdateScoreboard']._serialized_options = b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\036\032\034/scoreboards/{scoreboard_id}'
  _RANKER.methods_by_name['RebuildScoreboard']._options = None
  _RANKER.methods_by_name['RebuildScoreboard']._serialized_options = b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002&\"$/scoreboards/{scoreboard_id}/rebuild'
  _RANKER.methods_by_name['DeleteScoreboard']._options = None
  _RANKER.methods_by_name['DeleteScoreboard']._serialized_options = b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\036*\034/scoreboards/{scoreboard_id}'
  _RANKER.methods_by_name['DescribeScoreboard']._options = None
  _RANKER.methods_by_name['DescribeScoreboard']._serialized_options = b'\202\343\n\032\212\343\n\026ranker:scoreboard:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\036\022\034/scoreboards/{scoreboard_id}'
  _RANKER.methods_by_name['ListScoreboards']._options = None
  _RANKER.methods_by_name['ListScoreboards']._serialized_options = b'\202\343\n\032\212\343\n\026ranker:scoreboard:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\016\022\014/scoreboards'
  _RANKER.methods_by_name['DescribeScoreboardRow']._options = None
  _RANKER.methods_by_name['DescribeScoreboardRow']._serialized_options = b'\202\343\n\032\212\343\n\026ranker:scoreboard:read\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002/\022-/scoreboards/{scoreboard_id}/rows/{member_id}'
  _RANKER.methods_by_name['ListScoreboardRows']._options = None
  _RANKER.methods_by_name['ListScoreboardRows']._serialized_options = b'\202\343\n\032\212\343\n\026ranker:scoreboard:read\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002#\022!/scoreboards/{scoreboard_id}/rows'
  _RANKER.methods_by_name['AddScoreboardColumn']._options = None
  _RANKER.methods_by_name['AddScoreboardColumn']._serialized_options = b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002&\"$/scoreboards/{scoreboard_id}/columns'
  _RANKER.methods_by_name['DeleteScoreboardColumn']._options = None
  _RANKER.methods_by_name['DeleteScoreboardColumn']._serialized_options = b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\0022*0/scoreboards/{scoreboard_id}/columns/{column_id}'
  _RANKER.methods_by_name['DescribeScoreboardColumn']._options = None
  _RANKER.methods_by_name['DescribeScoreboardColumn']._serialized_options = b'\202\343\n\032\212\343\n\026ranker:scoreboard:read\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\0022\0220/scoreboards/{scoreboard_id}/columns/{column_id}'
  _RANKER.methods_by_name['ListScoreboardColumns']._options = None
  _RANKER.methods_by_name['ListScoreboardColumns']._serialized_options = b'\202\343\n\032\212\343\n\026ranker:scoreboard:read\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002&\022$/scoreboards/{scoreboard_id}/columns'
  _RANKER.methods_by_name['ListActivities']._options = None
  _RANKER.methods_by_name['ListActivities']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002)\022\'/scoreboards/{scoreboard_id}/activities'
  _CREATESCOREBOARDINPUT._serialized_start=275
  _CREATESCOREBOARDINPUT._serialized_end=345
  _CREATESCOREBOARDOUTPUT._serialized_start=347
  _CREATESCOREBOARDOUTPUT._serialized_end=394
  _UPDATESCOREBOARDINPUT._serialized_start=396
  _UPDATESCOREBOARDINPUT._serialized_end=489
  _UPDATESCOREBOARDOUTPUT._serialized_start=491
  _UPDATESCOREBOARDOUTPUT._serialized_end=515
  _REBUILDSCOREBOARDINPUT._serialized_start=517
  _REBUILDSCOREBOARDINPUT._serialized_end=564
  _REBUILDSCOREBOARDOUTPUT._serialized_start=566
  _REBUILDSCOREBOARDOUTPUT._serialized_end=612
  _DELETESCOREBOARDINPUT._serialized_start=614
  _DELETESCOREBOARDINPUT._serialized_end=660
  _DELETESCOREBOARDOUTPUT._serialized_start=662
  _DELETESCOREBOARDOUTPUT._serialized_end=686
  _DESCRIBESCOREBOARDINPUT._serialized_start=688
  _DESCRIBESCOREBOARDINPUT._serialized_end=760
  _DESCRIBESCOREBOARDOUTPUT._serialized_start=762
  _DESCRIBESCOREBOARDOUTPUT._serialized_end=835
  _LISTSCOREBOARDSINPUT._serialized_start=838
  _LISTSCOREBOARDSINPUT._serialized_end=1005
  _LISTSCOREBOARDSINPUT_FILTER._serialized_start=953
  _LISTSCOREBOARDSINPUT_FILTER._serialized_end=1005
  _LISTSCOREBOARDSOUTPUT._serialized_start=1007
  _LISTSCOREBOARDSOUTPUT._serialized_end=1087
  _DESCRIBESCOREBOARDROWINPUT._serialized_start=1089
  _DESCRIBESCOREBOARDROWINPUT._serialized_end=1159
  _DESCRIBESCOREBOARDROWOUTPUT._serialized_start=1161
  _DESCRIBESCOREBOARDROWOUTPUT._serialized_end=1234
  _LISTSCOREBOARDROWSINPUT._serialized_start=1237
  _LISTSCOREBOARDROWSINPUT._serialized_end=1440
  _LISTSCOREBOARDROWSINPUT_FILTER._serialized_start=1381
  _LISTSCOREBOARDROWSINPUT_FILTER._serialized_end=1440
  _LISTSCOREBOARDROWSOUTPUT._serialized_start=1442
  _LISTSCOREBOARDROWSOUTPUT._serialized_end=1529
  _ADDSCOREBOARDCOLUMNINPUT._serialized_start=1531
  _ADDSCOREBOARDCOLUMNINPUT._serialized_end=1630
  _ADDSCOREBOARDCOLUMNOUTPUT._serialized_start=1632
  _ADDSCOREBOARDCOLUMNOUTPUT._serialized_end=1678
  _DELETESCOREBOARDCOLUMNINPUT._serialized_start=1680
  _DELETESCOREBOARDCOLUMNINPUT._serialized_end=1751
  _DELETESCOREBOARDCOLUMNOUTPUT._serialized_start=1753
  _DELETESCOREBOARDCOLUMNOUTPUT._serialized_end=1783
  _DESCRIBESCOREBOARDCOLUMNINPUT._serialized_start=1785
  _DESCRIBESCOREBOARDCOLUMNINPUT._serialized_end=1858
  _DESCRIBESCOREBOARDCOLUMNOUTPUT._serialized_start=1860
  _DESCRIBESCOREBOARDCOLUMNOUTPUT._serialized_end=1942
  _LISTSCOREBOARDCOLUMNSINPUT._serialized_start=1944
  _LISTSCOREBOARDCOLUMNSINPUT._serialized_end=1995
  _LISTSCOREBOARDCOLUMNSOUTPUT._serialized_start=1997
  _LISTSCOREBOARDCOLUMNSOUTPUT._serialized_end=2090
  _LISTACTIVITIESINPUT._serialized_start=2092
  _LISTACTIVITIESINPUT._serialized_end=2166
  _LISTACTIVITIESOUTPUT._serialized_start=2168
  _LISTACTIVITIESOUTPUT._serialized_end=2245
  _RANKER._serialized_start=2248
  _RANKER._serialized_end=4771
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/community/community.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.community import attribute_pb2 as eolymp_dot_community_dot_attribute__pb2
from eolymp.community import member_pb2 as eolymp_dot_community_dot_member__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/community/community.proto\x12\x10\x65olymp.community\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a eolymp/community/attribute.proto\x1a\x1d\x65olymp/community/member.proto\x1a!eolymp/wellknown/expression.proto\"N\n\x0eJoinSpaceInput\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\x06values\x18\x14 \x03(\x0b\x32\x1e.eolymp.community.Member.Value\"2\n\x0fJoinSpaceOutput\x12\x0c\n\x03\x65rn\x18\x8fN \x01(\t\x12\x11\n\tmember_id\x18\x01 \x01(\t\"E\n\x13RegisterMemberInput\x12.\n\x06values\x18\x01 \x03(\x0b\x32\x1e.eolymp.community.Member.Value\"\x16\n\x14RegisterMemberOutput\"\x11\n\x0fLeaveSpaceInput\"\x12\n\x10LeaveSpaceOutput\":\n\x0e\x41\x64\x64MemberInput\x12(\n\x06member\x18\x01 \x01(\x0b\x32\x18.eolymp.community.Member\"2\n\x0f\x41\x64\x64MemberOutput\x12\x0c\n\x03\x65rn\x18\x8fN \x01(\t\x12\x11\n\tmember_id\x18\x01 \x01(\t\"P\n\x11UpdateMemberInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12(\n\x06member\x18\x02 \x01(\x0b\x32\x18.eolymp.community.Member\"\x14\n\x12UpdateMemberOutput\"&\n\x11RemoveMemberInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\"\x14\n\x12RemoveMemberOutput\"(\n\x13\x44\x65scribeMemberInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\"@\n\x14\x44\x65scribeMemberOutput\x12(\n\x06member\x18\x01 \x01(\x0b\x32\x18.eolymp.community.Member\"\x17\n\x15IntrospectMemberInput\"B\n\x16IntrospectMemberOutput\x12(\n\x06member\x18\x01 \x01(\x0b\x32\x18.eolymp.community.Member\"\xba\x02\n\x10ListMembersInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12:\n\x07\x66ilters\x18( \x01(\x0b\x32).eolymp.community.ListMembersInput.Filter\x1a\xcb\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x07user_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x32\n\x08\x64isabled\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x30\n\x04name\x18\x04 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\"K\n\x11ListMembersOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.community.Member\"Z\n\x11\x41\x64\x64\x41ttributeInput\x12\x15\n\rattribute_key\x18\x01 \x01(\t\x12.\n\tattribute\x18\x02 \x01(\x0b\x32\x1b.eolymp.community.Attribute\"\"\n\x12\x41\x64\x64\x41ttributeOutput\x12\x0c\n\x03\x65rn\x18\x8fN \x01(\t\"]\n\x14UpdateAttributeInput\x12\x15\n\rattribute_key\x18\x01 \x01(\t\x12.\n\tattribute\x18\x02 \x01(\x0b\x32\x1b.eolymp.community.Attribute\"\x17\n\x15UpdateAttributeOutput\"-\n\x14RemoveAttributeInput\x12\x15\n\rattribute_key\x18\x01 \x01(\t\"\x17\n\x15RemoveAttributeOutput\"/\n\x16\x44\x65scribeAttributeInput\x12\x15\n\rattribute_key\x18\x01 \x01(\t\"I\n\x17\x44\x65scribeAttributeOutput\x12.\n\tattribute\x18\x01 \x01(\x0b\x32\x1b.eolymp.community.Attribute\"\xee\x02\n\x13ListAttributesInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12=\n\x07\x66ilters\x18( \x01(\x0b\x32,.eolymp.community.ListAttributesInput.Filter\x1a\xf9\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12-\n\x03key\x18\x02 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x06hidden\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x32\n\x08required\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12.\n\x04type\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"Q\n\x14ListAttributesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12*\n\x05items\x18\x02 \x03(\x0b\x32\x1b.eolymp.community.Attribute2\x8b\x12\n\tCommunity\x12\x94\x01\n\tJoinSpace\x12 .eolymp.community.JoinSpaceInput\x1a!.eolymp.community.JoinSpaceOutput\"B\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:join\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x10\"\x0e/members/_self\x12\x97\x01\n\nLeaveSpace\x12!.eolymp.community.LeaveSpaceInput\x1a\".eolymp.community.LeaveSpaceOutput\"B\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:join\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x10*\x0e/members/_self\x12\xaf\x01\n\x0eRegisterMember\x12%.eolymp.community.RegisterMemberInput\x1a&.eolymp.community.RegisterMemberOutput\"N\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1b\"\x19/members/_self/attributes\x12\x8c\x01\n\x10IntrospectMember\x12\'.eolymp.community.IntrospectMemberInput\x1a(.eolymp.community.IntrospectMemberOutput\"%\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x10\x12\x0e/members/_self\x12\x8f\x01\n\tAddMember\x12 .eolymp.community.AddMemberInput\x1a!.eolymp.community.AddMemberOutput\"=\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\n\"\x08/members\x12\xa4\x01\n\x0cUpdateMember\x12#.eolymp.community.UpdateMemberInput\x1a$.eolymp.community.UpdateMemberOutput\"I\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x16\"\x14/members/{member_id}\x12\xa4\x01\n\x0cRemoveMember\x12#.eolymp.community.RemoveMemberInput\x1a$.eolymp.community.RemoveMemberOutput\"I\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x16*\x14/members/{member_id}\x12\xa9\x01\n\x0e\x44\x65scribeMember\x12%.eolymp.community.DescribeMemberInput\x1a&.eolymp.community.DescribeMemberOutput\"H\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x16\x12\x14/members/{member_id}\x12\x94\x01\n\x0bListMembers\x12\".eolymp.community.ListMembersInput\x1a#.eolymp.community.ListMembersOutput\"<\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\n\x12\x08/members\x12\x9b\x01\n\x0c\x41\x64\x64\x41ttribute\x12#.eolymp.community.AddAttributeInput\x1a$.eolymp.community.AddAttributeOutput\"@\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\r\"\x0b/attributes\x12\xb4\x01\n\x0fUpdateAttribute\x12&.eolymp.community.UpdateAttributeInput\x1a\'.eolymp.community.UpdateAttributeOutput\"P\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1d\"\x1b/attributes/{attribute_key}\x12\xb4\x01\n\x0fRemoveAttribute\x12&.eolymp.community.RemoveAttributeInput\x1a\'.eolymp.community.RemoveAttributeOutput\"P\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1d*\x1b/attributes/{attribute_key}\x12\xb9\x01\n\x11\x44\x65scribeAttribute\x12(.eolymp.community.DescribeAttributeInput\x1a).eolymp.community.DescribeAttributeOutput\"O\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1d\x12\x1b/attributes/{attribute_key}\x12\xa0\x01\n\x0eListAttributes\x12%.eolymp.community.ListAttributesInput\x1a&.eolymp.community.ListAttributesOutput\"?\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\r\"\x0b/attributesB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.community_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _COMMUNITY.methods_by_name['JoinSpace']._options = None
  _COMMUNITY.methods_by_name['JoinSpace']._serialized_options = b'\202\343\n\031\212\343\n\025community:member:join\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\020\"\016/members/_self'
  _COMMUNITY.methods_by_name['LeaveSpace']._options = None
  _COMMUNITY.methods_by_name['LeaveSpace']._serialized_options = b'\202\343\n\031\212\343\n\025community:member:join\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\020*\016/members/_self'
  _COMMUNITY.methods_by_name['RegisterMember']._options = None
  _COMMUNITY.methods_by_name['RegisterMember']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\033\"\031/members/_self/attributes'
  _COMMUNITY.methods_by_name['IntrospectMember']._options = None
  _COMMUNITY.methods_by_name['IntrospectMember']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\020\022\016/members/_self'
  _COMMUNITY.methods_by_name['AddMember']._options = None
  _COMMUNITY.methods_by_name['AddMember']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\n\"\010/members'
  _COMMUNITY.methods_by_name['UpdateMember']._options = None
  _COMMUNITY.methods_by_name['UpdateMember']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\026\"\024/members/{member_id}'
  _COMMUNITY.methods_by_name['RemoveMember']._options = None
  _COMMUNITY.methods_by_name['RemoveMember']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\026*\024/members/{member_id}'
  _COMMUNITY.methods_by_name['DescribeMember']._options = None
  _COMMUNITY.methods_by_name['DescribeMember']._serialized_options = b'\202\343\n\031\212\343\n\025community:member:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\026\022\024/members/{member_id}'
  _COMMUNITY.methods_by_name['ListMembers']._options = None
  _COMMUNITY.methods_by_name['ListMembers']._serialized_options = b'\202\343\n\031\212\343\n\025community:member:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\n\022\010/members'
  _COMMUNITY.methods_by_name['AddAttribute']._options = None
  _COMMUNITY.methods_by_name['AddAttribute']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\r\"\013/attributes'
  _COMMUNITY.methods_by_name['UpdateAttribute']._options = None
  _COMMUNITY.methods_by_name['UpdateAttribute']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\035\"\033/attributes/{attribute_key}'
  _COMMUNITY.methods_by_name['RemoveAttribute']._options = None
  _COMMUNITY.methods_by_name['RemoveAttribute']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\035*\033/attributes/{attribute_key}'
  _COMMUNITY.methods_by_name['DescribeAttribute']._options = None
  _COMMUNITY.methods_by_name['DescribeAttribute']._serialized_options = b'\202\343\n\031\212\343\n\025community:member:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\035\022\033/attributes/{attribute_key}'
  _COMMUNITY.methods_by_name['ListAttributes']._options = None
  _COMMUNITY.methods_by_name['ListAttributes']._serialized_options = b'\202\343\n\031\212\343\n\025community:member:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\r\"\013/attributes'
  _JOINSPACEINPUT._serialized_start=253
  _JOINSPACEINPUT._serialized_end=331
  _JOINSPACEOUTPUT._serialized_start=333
  _JOINSPACEOUTPUT._serialized_end=383
  _REGISTERMEMBERINPUT._serialized_start=385
  _REGISTERMEMBERINPUT._serialized_end=454
  _REGISTERMEMBEROUTPUT._serialized_start=456
  _REGISTERMEMBEROUTPUT._serialized_end=478
  _LEAVESPACEINPUT._serialized_start=480
  _LEAVESPACEINPUT._serialized_end=497
  _LEAVESPACEOUTPUT._serialized_start=499
  _LEAVESPACEOUTPUT._serialized_end=517
  _ADDMEMBERINPUT._serialized_start=519
  _ADDMEMBERINPUT._serialized_end=577
  _ADDMEMBEROUTPUT._serialized_start=579
  _ADDMEMBEROUTPUT._serialized_end=629
  _UPDATEMEMBERINPUT._serialized_start=631
  _UPDATEMEMBERINPUT._serialized_end=711
  _UPDATEMEMBEROUTPUT._serialized_start=713
  _UPDATEMEMBEROUTPUT._serialized_end=733
  _REMOVEMEMBERINPUT._serialized_start=735
  _REMOVEMEMBERINPUT._serialized_end=773
  _REMOVEMEMBEROUTPUT._serialized_start=775
  _REMOVEMEMBEROUTPUT._serialized_end=795
  _DESCRIBEMEMBERINPUT._serialized_start=797
  _DESCRIBEMEMBERINPUT._serialized_end=837
  _DESCRIBEMEMBEROUTPUT._serialized_start=839
  _DESCRIBEMEMBEROUTPUT._serialized_end=903
  _INTROSPECTMEMBERINPUT._serialized_start=905
  _INTROSPECTMEMBERINPUT._serialized_end=928
  _INTROSPECTMEMBEROUTPUT._serialized_start=930
  _INTROSPECTMEMBEROUTPUT._serialized_end=996
  _LISTMEMBERSINPUT._serialized_start=999
  _LISTMEMBERSINPUT._serialized_end=1313
  _LISTMEMBERSINPUT_FILTER._serialized_start=1110
  _LISTMEMBERSINPUT_FILTER._serialized_end=1313
  _LISTMEMBERSOUTPUT._serialized_start=1315
  _LISTMEMBERSOUTPUT._serialized_end=1390
  _ADDATTRIBUTEINPUT._serialized_start=1392
  _ADDATTRIBUTEINPUT._serialized_end=1482
  _ADDATTRIBUTEOUTPUT._serialized_start=1484
  _ADDATTRIBUTEOUTPUT._serialized_end=1518
  _UPDATEATTRIBUTEINPUT._serialized_start=1520
  _UPDATEATTRIBUTEINPUT._serialized_end=1613
  _UPDATEATTRIBUTEOUTPUT._serialized_start=1615
  _UPDATEATTRIBUTEOUTPUT._serialized_end=1638
  _REMOVEATTRIBUTEINPUT._serialized_start=1640
  _REMOVEATTRIBUTEINPUT._serialized_end=1685
  _REMOVEATTRIBUTEOUTPUT._serialized_start=1687
  _REMOVEATTRIBUTEOUTPUT._serialized_end=1710
  _DESCRIBEATTRIBUTEINPUT._serialized_start=1712
  _DESCRIBEATTRIBUTEINPUT._serialized_end=1759
  _DESCRIBEATTRIBUTEOUTPUT._serialized_start=1761
  _DESCRIBEATTRIBUTEOUTPUT._serialized_end=1834
  _LISTATTRIBUTESINPUT._serialized_start=1837
  _LISTATTRIBUTESINPUT._serialized_end=2203
  _LISTATTRIBUTESINPUT_FILTER._serialized_start=1954
  _LISTATTRIBUTESINPUT_FILTER._serialized_end=2203
  _LISTATTRIBUTESOUTPUT._serialized_start=2205
  _LISTATTRIBUTESOUTPUT._serialized_end=2286
  _COMMUNITY._serialized_start=2289
  _COMMUNITY._serialized_end=4604
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/annotations/resource.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!eolymp/annotations/resource.proto\x12\neolymp.api\x1a google/protobuf/descriptor.proto\"@\n\x08Resource\x12\x12\n\x08id_field\x18\xb9\xac\x01 \x01(\t\x12\x0e\n\x04type\x18\xb7\xac\x01 \x01(\t\x12\x10\n\x06parent\x18\xb8\xac\x01 \x01(\t:I\n\x08resource\x12\x1f.google.protobuf.MessageOptions\x18\xb6\xac\x01 \x01(\x0b\x32\x14.eolymp.api.ResourceB9Z7github.com/eolymp/go-sdk/eolymp/annotations;annotationsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.annotations.resource_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(resource)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z7github.com/eolymp/go-sdk/eolymp/annotations;annotations'
  _RESOURCE._serialized_start=83
  _RESOURCE._serialized_end=147
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.annotations import service_pb2 as _service_pb2
from eolymp.ranker import activity_pb2 as _activity_pb2
from eolymp.ranker import scoreboard_pb2 as _scoreboard_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AddScoreboardColumnInput(_message.Message):
    __slots__ = ["column", "scoreboard_id"]
    COLUMN_FIELD_NUMBER: _ClassVar[int]
    SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    column: _scoreboard_pb2.Scoreboard.Column
    scoreboard_id: str
    def __init__(self, scoreboard_id: _Optional[str] = ..., column: _Optional[_Union[_scoreboard_pb2.Scoreboard.Column, _Mapping]] = ...) -> None: ...

class AddScoreboardColumnOutput(_message.Message):
    __slots__ = ["column_id"]
    COLUMN_ID_FIELD_NUMBER: _ClassVar[int]
    column_id: str
    def __init__(self, column_id: _Optional[str] = ...) -> None: ...

class CreateScoreboardInput(_message.Message):
    __slots__ = ["scoreboard"]
    SCOREBOARD_FIELD_NUMBER: _ClassVar[int]
    scoreboard: _scoreboard_pb2.Scoreboard
    def __init__(self, scoreboard: _Optional[_Union[_scoreboard_pb2.Scoreboard, _Mapping]] = ...) -> None: ...

class CreateScoreboardOutput(_message.Message):
    __slots__ = ["scoreboard_id"]
    SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    scoreboard_id: str
    def __init__(self, scoreboard_id: _Optional[str] = ...) -> None: ...

class DeleteScoreboardColumnInput(_message.Message):
    __slots__ = ["column_id", "scoreboard_id"]
    COLUMN_ID_FIELD_NUMBER: _ClassVar[int]
    SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    column_id: str
    scoreboard_id: str
    def __init__(self, scoreboard_id: _Optional[str] = ..., column_id: _Optional[str] = ...) -> None: ...

class DeleteScoreboardColumnOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DeleteScoreboardInput(_message.Message):
    __slots__ = ["scoreboard_id"]
    SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    scoreboard_id: str
    def __init__(self, scoreboard_id: _Optional[str] = ...) -> None: ...

class DeleteScoreboardOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribeScoreboardColumnInput(_message.Message):
    __slots__ = ["column_id", "scoreboard_id"]
    COLUMN_ID_FIELD_NUMBER: _ClassVar[int]
    SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    column_id: str
    scoreboard_id: str
    def __init__(self, scoreboard_id: _Optional[str] = ..., column_id: _Optional[str] = ...) -> None: ...

class DescribeScoreboardColumnOutput(_message.Message):
    __slots__ = ["column"]
    COLUMN_FIELD_NUMBER: _ClassVar[int]
    column: _scoreboard_pb2.Scoreboard.Column
    def __init__(self, column: _Optional[_Union[_scoreboard_pb2.Scoreboard.Column, _Mapping]] = ...) -> None: ...

class DescribeScoreboardInput(_message.Message):
    __slots__ = ["scoreboard_id", "scoreboard_key"]
    SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    SCOREBOARD_KEY_FIELD_NUMBER: _ClassVar[int]
    scoreboard_id: str
    scoreboard_key: str
    def __init__(self, scoreboard_id: _Optional[str] = ..., scoreboard_key: _Optional[str] = ...) -> None: ...

class DescribeScoreboardOutput(_message.Message):
    __slots__ = ["scoreboard"]
    SCOREBOARD_FIELD_NUMBER: _ClassVar[int]
    scoreboard: _scoreboard_pb2.Scoreboard
    def __init__(self, scoreboard: _Optional[_Union[_scoreboard_pb2.Scoreboard, _Mapping]] = ...) -> None: ...

class DescribeScoreboardRowInput(_message.Message):
    __slots__ = ["member_id", "scoreboard_id"]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    member_id: str
    scoreboard_id: str
    def __init__(self, scoreboard_id: _Optional[str] = ..., member_id: _Optional[str] = ...) -> None: ...

class DescribeScoreboardRowOutput(_message.Message):
    __slots__ = ["row"]
    ROW_FIELD_NUMBER: _ClassVar[int]
    row: _scoreboard_pb2.Scoreboard.Row
    def __init__(self, row: _Optional[_Union[_scoreboard_pb2.Scoreboard.Row, _Mapping]] = ...) -> None: ...

class ListActivitiesInput(_message.Message):
    __slots__ = ["offset", "scoreboard_id", "size"]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    offset: int
    scoreboard_id: str
    size: int
    def __init__(self, scoreboard_id: _Optional[str] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ...) -> None: ...

class ListActivitiesOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_activity_pb2.Activity]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_activity_pb2.Activity, _Mapping]]] = ...) -> None: ...

class ListScoreboardColumnsInput(_message.Message):
    __slots__ = ["scoreboard_id"]
    SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    scoreboard_id: str
    def __init__(self, scoreboard_id: _Optional[str] = ...) -> None: ...

class ListScoreboardColumnsOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_scoreboard_pb2.Scoreboard.Column]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_scoreboard_pb2.Scoreboard.Column, _Mapping]]] = ...) -> None: ...

class ListScoreboardRowsInput(_message.Message):
    __slots__ = ["filters", "offset", "scoreboard_id", "size"]
    class Filter(_message.Message):
        __slots__ = ["member_id"]
        MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
        member_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        def __init__(self, member_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ...) -> None: ...
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    filters: ListScoreboardRowsInput.Filter
    offset: int
    scoreboard_id: str
    size: int
    def __init__(self, scoreboard_id: _Optional[str] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListScoreboardRowsInput.Filter, _Mapping]] = ...) -> None: ...

class ListScoreboardRowsOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_scoreboard_pb2.Scoreboard.Row]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_scoreboard_pb2.Scoreboard.Row, _Mapping]]] = ...) -> None: ...

class ListScoreboardsInput(_message.Message):
    __slots__ = ["filters", "offset", "size"]
    class Filter(_message.Message):
        __slots__ = ["id"]
        ID_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ...) -> None: ...
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    filters: ListScoreboardsInput.Filter
    offset: int
    size: int
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListScoreboardsInput.Filter, _Mapping]] = ...) -> None: ...

class ListScoreboardsOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_scoreboard_pb2.Scoreboard]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_scoreboard_pb2.Scoreboard, _Mapping]]] = ...) -> None: ...

class RebuildScoreboardInput(_message.Message):
    __slots__ = ["scoreboard_id"]
    SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    scoreboard_id: str
    def __init__(self, scoreboard_id: _Optional[str] = ...) -> None: ...

class RebuildScoreboardOutput(_message.Message):
    __slots__ = ["activity_id"]
    ACTIVITY_ID_FIELD_NUMBER: _ClassVar[int]
    activity_id: str
    def __init__(self, activity_id: _Optional[str] = ...) -> None: ...

class UpdateScoreboardInput(_message.Message):
    __slots__ = ["scoreboard", "scoreboard_id"]
    SCOREBOARD_FIELD_NUMBER: _ClassVar[int]
    SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    scoreboard: _scoreboard_pb2.Scoreboard
    scoreboard_id: str
    def __init__(self, scoreboard_id: _Optional[str] = ..., scoreboard: _Optional[_Union[_scoreboard_pb2.Scoreboard, _Mapping]] = ...) -> None: ...

class UpdateScoreboardOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/playground/run.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.executor import usage_pb2 as eolymp_dot_executor_dot_usage__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65olymp/playground/run.proto\x12\x11\x65olymp.playground\x1a\x1b\x65olymp/executor/usage.proto\"\x9b\x04\n\x03Run\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04lang\x18\t \x01(\t\x12\x0f\n\x07runtime\x18\n \x01(\t\x12\x0e\n\x06source\x18\x0b \x01(\t\x12\x12\n\nsource_ern\x18\x0c \x01(\t\x12\r\n\x05input\x18\r \x01(\t\x12\x11\n\tinput_ern\x18\x0e \x01(\t\x12-\n\x06status\x18\x14 \x01(\x0e\x32\x1d.eolymp.playground.Run.Status\x12\r\n\x05\x65rror\x18\x15 \x01(\t\x12\x11\n\texit_code\x18\x1e \x01(\r\x12\x0e\n\x06signal\x18\x1f \x01(\r\x12\x17\n\x0fwall_time_usage\x18  \x01(\r\x12\x16\n\x0e\x63pu_time_usage\x18! \x01(\r\x12\x14\n\x0cmemory_usage\x18\" \x01(\x04\x12\x36\n\x0eresource_usage\x18# \x01(\x0b\x32\x1e.eolymp.executor.ResourceUsage\x12\x0e\n\x06output\x18( \x01(\t\x12\x12\n\noutput_ern\x18) \x01(\t\x12\x13\n\x0bproblem_ern\x18\x32 \x01(\t\"\x89\x01\n\x06Status\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\r\n\tEXECUTING\x10\x02\x12\x0c\n\x08\x45XECUTED\x10\x03\x12\x0b\n\x07TIMEOUT\x10\x04\x12\x11\n\rCPU_EXHAUSTED\x10\x05\x12\x13\n\x0fMEMORY_OVERFLOW\x10\x06\x12\t\n\x05\x45RROR\x10\x07\x12\x0b\n\x07\x46\x41ILURE\x10\x08\x42\x37Z5github.com/eolymp/go-sdk/eolymp/playground;playgroundb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.playground.run_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/playground;playground'
  _RUN._serialized_start=80
  _RUN._serialized_end=619
  _RUN_STATUS._serialized_start=482
  _RUN_STATUS._serialized_end=619
# @@protoc_insertion_point(module_scope)
